pub struct DecreaseLiquidity {
pub liquidity_amount: u128,
pub token_min_a: u64,
pub token_min_b: u64,
}Expand description
Withdraw liquidity from a position in the Whirlpool. This call also updates the position’s accrued fees and rewards. ### Authority
position_authority- authority that owns the token corresponding to this desired position.
Parameters
liquidity_amount- The total amount of Liquidity the user desires to withdraw.token_min_a- The minimum amount of tokenA the user is willing to withdraw.token_min_b- The minimum amount of tokenB the user is willing to withdraw.
Special Errors
LiquidityZero- Provided liquidity amount is zero.LiquidityTooHigh- Provided liquidity exceeds u128::max.TokenMinSubceeded- The required token to perform this operation subceeds the user defined amount.
Fields
liquidity_amount: u128token_min_a: u64token_min_b: u64Implementations