pub struct InitializeDynamicTickArray {
pub start_tick_index: i32,
pub idempotent: bool,
}Expand description
Initialize a variable-length tick array for a Whirlpool.
Parameters
start_tick_index- The starting tick index for this tick-array.
Has to be a multiple of TickArray size & the tick spacing of this pool.
idempotent- If true, the instruction will not fail if the tick array already exists.
Note: The idempotent option exits successfully if a FixedTickArray is present as well as a DynamicTickArray. #### Special Errors
InvalidStartTick- if the provided start tick is out of bounds or is not a multiple of
TICK_ARRAY_SIZE * tick spacing.
Fields
start_tick_index: i32idempotent: boolImplementations